@@ -25,7 +25,7 @@ pub struct GeneratePlanOptions {
 }
 
 pub struct NixpacksBuildPlanGenerator<'a> {
-    providers: &'a [&'a dyn Provider],
+    providers: &'a [&'a (dyn Provider)],
     config: GeneratePlanOptions,
 }
 
@@ -47,7 +47,7 @@ impl<'a> PlanGenerator for NixpacksBuildPlanGenerator<'a> {
 
 impl NixpacksBuildPlanGenerator<'_> {
     pub fn new<'a>(
-        providers: &'a [&'a dyn Provider],
+        providers: &'a [&'a (dyn Provider)],
         config: GeneratePlanOptions,
     ) -> NixpacksBuildPlanGenerator<'a> {
         NixpacksBuildPlanGenerator { providers, config }
@@ -57,6 +57,12 @@ impl NixpacksBuildPlanGenerator<'_> {
     fn get_build_plan(&self, app: &App, env: &Environment) -> Result<BuildPlan> {
         let plan_before_providers = self.get_plan_before_providers(app, env)?;
 
+        // Add the variables from the nixpacks.toml to environment
+        let env = &Environment::append_variables(
+            env,
+            plan_before_providers.variables.clone().unwrap_or_default(),
+        );
+
         let provider_plan =
             self.get_plan_from_providers(app, env, plan_before_providers.providers.clone())?;
 
@@ -71,7 +77,7 @@ impl NixpacksBuildPlanGenerator<'_> {
             plan.add_variables(Environment::clone_variables(env));
         }
 
-        plan.pin();
+        plan.pin(env.is_config_variable_truthy("DEBIAN"));
 
         Ok(plan)
     }
